@@ -1,5 +1,5 @@
 from . import abbreviations
-from . import array_parm
+from . import array_param
 from . import macro_files
 from . import matrix_op
 from . import parameter_definition
