@@ -5,7 +5,6 @@ it to a file, or annotate it with titles and systems of units.
 
 
 class Setup:
-
     def resume(self, fname="", ext="", nopar="", knoplot="", **kwargs):
         """Resumes the database from the database file.
 
@@ -253,9 +252,19 @@ class Setup:
         """
         return self.run(f"/TITLE,{title}", **kwargs)
 
-    def units(self, label="", lenfact="", massfact="", timefact="",
-              tempfact="", toffset="", chargefact="", forcefact="",
-              heatfact="", **kwargs):
+    def units(
+        self,
+        label="",
+        lenfact="",
+        massfact="",
+        timefact="",
+        tempfact="",
+        toffset="",
+        chargefact="",
+        forcefact="",
+        heatfact="",
+        **kwargs,
+    ):
         """Annotates the database with the system of units used.
 
         APDL Command: /UNITS
@@ -320,6 +329,15 @@ class Setup:
 
         This command is valid in any processor.
         """
-        command = "/UNITS,%s,%s,%s,%s,%s,%s,%s,%s,%s" % (str(label), str(lenfact), str(massfact), str(
-            timefact), str(tempfact), str(toffset), str(chargefact), str(forcefact), str(heatfact))
+        command = "/UNITS,%s,%s,%s,%s,%s,%s,%s,%s,%s" % (
+            str(label),
+            str(lenfact),
+            str(massfact),
+            str(timefact),
+            str(tempfact),
+            str(toffset),
+            str(chargefact),
+            str(forcefact),
+            str(heatfact),
+        )
         return self.run(command, **kwargs)
