@@ -1,5 +1,4 @@
 class Inertia:
-
     def acel(self, acel_x="", acel_y="", acel_z="", **kwargs):
         """Specifies the linear acceleration of the global Cartesian reference
 
@@ -45,7 +44,7 @@ class Inertia:
 
         The ACEL command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for ACEL_X, ACEL_Y, and ACEL_Z input
-        values (*DIM) as a function of both time and frequency for full
+        values (``*DIM``) as a function of both time and frequency for full
         transient and harmonic analyses.
 
         Related commands for rotational effects are CMACEL, CGLOC, CGOMGA,
@@ -137,15 +136,14 @@ class Inertia:
 
         The CGOMGA command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for CGOMGA_X, CGOMGA_Y, and CGOMGA_Z
-        input values (*DIM) for full transient and harmonic analyses.
+        input values (``*DIM``) for full transient and harmonic analyses.
 
         This command is also valid in PREP7.
         """
         command = f"CGOMGA,{cgomx},{cgomy},{cgomz}"
         return self.run(command, **kwargs)
 
-    def cmacel(self, cm_name="", cmacel_x="", cmacel_y="", cmacel_z="",
-               **kwargs):
+    def cmacel(self, cm_name="", cmacel_x="", cmacel_y="", cmacel_z="", **kwargs):
         """Specifies the translational acceleration of an element component
 
         APDL Command: CMACEL
@@ -197,7 +195,7 @@ class Inertia:
 
         The CMACEL command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for CMACEL_X, CMACEL_Y, and CMACEL_Z
-        input values (*DIM) as a function of both time and frequency for full
+        input values (``*DIM``) as a function of both time and frequency for full
         transient and harmonic analyses.
 
         Related commands for inertia loads are ACEL, CGLOC, CGOMGA, DCGOMG,
@@ -211,8 +209,20 @@ class Inertia:
         command = f"CMACEL,{cm_name},{cmacel_x},{cmacel_y},{cmacel_z}"
         return self.run(command, **kwargs)
 
-    def cmdomega(self, cm_name="", domegax="", domegay="", domegaz="", x1="",
-                 y1="", z1="", x2="", y2="", z2="", **kwargs):
+    def cmdomega(
+        self,
+        cm_name="",
+        domegax="",
+        domegay="",
+        domegaz="",
+        x1="",
+        y1="",
+        z1="",
+        x2="",
+        y2="",
+        z2="",
+        **kwargs,
+    ):
         """Specifies the rotational acceleration of an element component about a
 
         APDL Command: CMDOMEGA
@@ -251,7 +261,7 @@ class Inertia:
 
         The CMDOMEGA command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for CMDOMEGA_X, CMDOMEGA_Y, and
-        CMDOMEGA_Z input values (*DIM) for full transient and harmonic
+        CMDOMEGA_Z input values (``*DIM``) for full transient and harmonic
         analyses.
 
         Related commands are ACEL, CGLOC, CGLOC, OMEGA, CMOMEGA, DCGOMG,
@@ -283,8 +293,20 @@ class Inertia:
         command = f"CMDOMEGA,{cm_name},{domegax},{domegay},{domegaz},{x1},{y1},{z1},{x2},{y2},{z2}"
         return self.run(command, **kwargs)
 
-    def cmomega(self, cm_name="", omegax="", omegay="", omegaz="", x1="",
-                y1="", z1="", x2="", y2="", z2="", **kwargs):
+    def cmomega(
+        self,
+        cm_name="",
+        omegax="",
+        omegay="",
+        omegaz="",
+        x1="",
+        y1="",
+        z1="",
+        x2="",
+        y2="",
+        z2="",
+        **kwargs,
+    ):
         """Specifies the rotational velocity of an element component about a user-
 
         APDL Command: CMOMEGA
@@ -357,7 +379,7 @@ class Inertia:
 
         The CMOMEGA command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for CMOMEGA_X, CMOMEGA_Y, and CMOMEGA_Z
-        input values (*DIM) for full transient and harmonic analyses.
+        input values (``*DIM``) for full transient and harmonic analyses.
 
         In a mode-superposition harmonic or transient analysis, you must apply
         the load in the modal portion of the analysis. Mechanical APDL
@@ -367,8 +389,20 @@ class Inertia:
         command = f"CMOMEGA,{cm_name},{omegax},{omegay},{omegaz},{x1},{y1},{z1},{x2},{y2},{z2}"
         return self.run(command, **kwargs)
 
-    def cmrotate(self, cm_name="", rotatx="", rotaty="", rotatz="", x1="",
-                 y1="", z1="", x2="", y2="", z2="", **kwargs):
+    def cmrotate(
+        self,
+        cm_name="",
+        rotatx="",
+        rotaty="",
+        rotatz="",
+        x1="",
+        y1="",
+        z1="",
+        x2="",
+        y2="",
+        z2="",
+        **kwargs,
+    ):
         """Specifies the rotational velocity of an element component in a brake
 
         APDL Command: CMROTATE
@@ -456,16 +490,6 @@ class Inertia:
 
            ``"OFF"``, ``"NO"``, or ``False`` - Deactivate. This value is the default.
 
-        Examples
-        --------
-        Enable the coriolis effect with a stationary reference frame.
-
-        >>> mapdl.coriolis('ON', refframe='ON')
-
-        Alternatively, ``coriolis`` supports bool parameters.
-
-        >>> mapdl.coriolis(True, refframe=True)
-
         Notes
         -----
         The CORIOLIS command is used for analyses in either a rotating
@@ -532,6 +556,17 @@ class Inertia:
         Coriolis effects (rotating and stationary reference frames).
 
         This command is also valid in PREP7.
+
+        Examples
+        --------
+        Enable the coriolis effect with a stationary reference frame.
+
+        >>> mapdl.coriolis('ON', refframe='ON')
+
+        Alternatively, ``coriolis`` supports bool parameters.
+
+        >>> mapdl.coriolis(True, refframe=True)
+
         """
         # handle bool instead of strings
         if isinstance(option, bool):
@@ -571,7 +606,7 @@ class Inertia:
 
         The DCGOMG command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for DCGOMG_X, DCGOMG_Y, and DCGOMG_Z
-        input values (*DIM) for full transient and harmonic analyses.
+        input values (``*DIM``) for full transient and harmonic analyses.
 
          Related commands are ACEL, CGLOC, CGOMGA, DOMEGA, and OMEGA.
 
@@ -605,7 +640,7 @@ class Inertia:
 
         The DOMEGA command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for DOMEGA_X, DOMEGA_Y, and DOMEGA_Z
-        input values (*DIM) for full transient and harmonic analyses.
+        input values (``*DIM``) for full transient and harmonic analyses.
 
         Related commands are ACEL, CGLOC, CGOMGA, DCGOMG, and OMEGA.
 
@@ -713,7 +748,7 @@ class Inertia:
 
         The OMEGA command supports tabular boundary conditions (%TABNAME_X%,
         %TABNAME_Y%, and %TABNAME_Z%) for OMEGA_X, OMEGA_Y, and OMEGA_Z input
-        values (*DIM) for full transient and harmonic analyses.
+        values (``*DIM``) for full transient and harmonic analyses.
 
         Rotational velocities are combined with the element mass matrices to
         form a body force load vector term.  Units are radians/time.  Related
