@@ -1,5 +1,7 @@
 """pymapdl specific errors"""
-import logging
+
+from ansys.mapdl.core import LOG as logger
+
 import threading
 import signal
 from functools import wraps
@@ -8,8 +10,6 @@ from grpc._channel import _InactiveRpcError, _MultiThreadedRendezvous
 
 SIGINT_TRACKER = []
 
-logger = logging.getLogger(__name__)
-
 
 LOCKFILE_MSG = """
 Another ANSYS job with the same job name is already running in this
@@ -21,8 +21,10 @@ Disable this check by passing ``override=True``
 """
 
 
-TYPE_MSG = 'Invalid datatype.  Must be one of the following:\n' +\
-    'np.int32, np.int64, or np.double'
+TYPE_MSG = (
+    "Invalid datatype.  Must be one of the following:\n"
+    + "np.int32, np.int64, or np.double"
+)
 
 
 class ANSYSDataTypeError(ValueError):
@@ -35,46 +37,57 @@ class ANSYSDataTypeError(ValueError):
 class VersionError(ValueError):
     """Raised when MAPDL is the wrong version"""
 
-    def __init__(self, msg='Invalid MAPDL version'):
+    def __init__(self, msg="Invalid MAPDL version"):
         ValueError.__init__(self, msg)
 
 
 class NoDistributedFiles(FileNotFoundError):
-    """Unable to find any distributed result files """
+    """Unable to find any distributed result files"""
 
-    def __init__(self, msg='Unable to find any distributed result files'):
+    def __init__(self, msg="Unable to find any distributed result files"):
         FileNotFoundError.__init__(self, msg)
 
 
 class MapdlRuntimeError(RuntimeError):
     """Raised when MAPDL passes an error"""
+
     pass
 
 
 class MapdlInvalidRoutineError(RuntimeError):
     """Raised when MAPDL is in the wrong routine"""
-    def __init__(self, msg=''):
+
+    def __init__(self, msg=""):
         RuntimeError.__init__(self, msg)
 
 
 class MapdlExitedError(RuntimeError):
     """Raised when MAPDL has exited"""
 
-    def __init__(self, msg='MAPDL has exited'):
+    def __init__(self, msg="MAPDL has exited"):
         RuntimeError.__init__(self, msg)
 
 
 class LockFileException(RuntimeError):
     """Error message when the lockfile has not been removed"""
+
     def __init__(self, msg=LOCKFILE_MSG):
         RuntimeError.__init__(self, msg)
 
 
+class LicenseServerConnectionError(RuntimeError):
+    """Error when the license server is not available."""
+
+    def __init__(self, msg=""):
+        RuntimeError.__init__(self, msg)
+
+
 # handler for protect_grpc
 def handler(sig, frame):  # pragma: no cover
     """Pass signal to custom interrupt handler."""
-    logger.info('KeyboardInterrupt received.  Waiting until MAPDL '
-                'execution finishes')
+    logger.info(
+        "KeyboardInterrupt received.  Waiting until MAPDL " "execution finishes"
+    )
     SIGINT_TRACKER.append(True)
 
 
@@ -87,13 +100,14 @@ def protect_grpc(func):
     reason gRPC still captures SIGINT.
 
     """
+
     @wraps(func)
     def wrapper(*args, **kwargs):
         """Capture gRPC exceptions and KeyboardInterrupt"""
 
         # capture KeyboardInterrupt
         old_handler = None
-        if threading.current_thread().__class__.__name__ == '_MainThread':
+        if threading.current_thread().__class__.__name__ == "_MainThread":
             if threading.current_thread().is_alive():
                 old_handler = signal.signal(signal.SIGINT, handler)
 
@@ -105,18 +119,18 @@ def protect_grpc(func):
             try:
                 class_name = args[0].__class__.__name__
             except:
-                class_name = ''
+                class_name = ""
 
-            if class_name == 'MapdlGrpc':
+            if class_name == "MapdlGrpc":
                 mapdl = args[0]
-            elif hasattr(args[0], '_mapdl'):
+            elif hasattr(args[0], "_mapdl"):
                 mapdl = args[0]._mapdl
 
             # Must close unfinished processes
             mapdl._close_process()
-            raise MapdlExitedError('MAPDL server connection terminated') from None
+            raise MapdlExitedError("MAPDL server connection terminated") from None
 
-        if threading.current_thread().__class__.__name__ == '_MainThread':
+        if threading.current_thread().__class__.__name__ == "_MainThread":
             received_interrupt = bool(SIGINT_TRACKER)
 
             # always clear and revert to old handler
@@ -125,7 +139,7 @@ def protect_grpc(func):
                 signal.signal(signal.SIGINT, old_handler)
 
             if received_interrupt:  # pragma: no cover
-                raise KeyboardInterrupt('Interrupted during MAPDL execution')
+                raise KeyboardInterrupt("Interrupted during MAPDL execution")
 
         return out
 
