@@ -6,17 +6,19 @@ import inspect
 
 module_path = os.path.dirname(inspect.getfile(inspect.currentframe()))
 
+
 def load_vmfiles():
-    """load vmfiles and store their filenames """
+    """load vmfiles and store their filenames"""
     vmfiles = {}
-    verif_path = os.path.join(module_path, 'verif')
-    for filename in glob.glob(os.path.join(verif_path, '*dat')):
+    verif_path = os.path.join(module_path, "verif")
+    for filename in glob.glob(os.path.join(verif_path, "*dat")):
         basename = os.path.basename(filename)
         vmname = os.path.splitext(basename)[0]
         vmfiles[vmname] = filename
 
     return vmfiles
 
+
 # save the module from failing if the verification files are unavailable.
 try:
     vmfiles = load_vmfiles()
