@@ -1,4 +1,5 @@
-"""CORBA implementation of the MAPDL interface"""
+"""CORBA implementation of the MAPDL interface."""
+import sys
 import atexit
 import subprocess
 import time
@@ -10,10 +11,16 @@ from ansys.mapdl.core.mapdl import _MapdlCore
 from ansys.mapdl.core.misc import threaded, random_string
 from ansys.mapdl.core.errors import MapdlRuntimeError, MapdlExitedError
 
+if sys.version_info[1] > 8:
+    raise ImportError(
+        "The CORBA interface is only supported for Python 3.8" " and earlier"
+    )
+
 from ansys_corba import CORBA
 
 INSTANCES = []
 
+
 @atexit.register
 def _cleanup():
     for instance in INSTANCES:
@@ -25,7 +32,7 @@ def _cleanup():
 
 
 def tail(filename, nlines):
-    """Read the last nlines of a text file """
+    """Read the last nlines of a text file"""
     with open(filename) as qfile:
         qfile.seek(0, os.SEEK_END)
         endf = position = qfile.tell()
@@ -33,7 +40,7 @@ def tail(filename, nlines):
         while position >= 0:
             qfile.seek(position)
             next_char = qfile.read(1)
-            if next_char == "\n" and position != endf-1:
+            if next_char == "\n" and position != endf - 1:
                 linecnt += 1
 
             if linecnt == nlines:
@@ -46,8 +53,15 @@ def tail(filename, nlines):
         return qfile.read()
 
 
-def launch_corba(exec_file=None, run_location=None, jobname=None, nproc=None,
-                 verbose=False, additional_switches='', start_timeout=60):
+def launch_corba(
+    exec_file=None,
+    run_location=None,
+    jobname=None,
+    nproc=None,
+    verbose=False,
+    additional_switches="",
+    start_timeout=60,
+):
     """Start MAPDL in AAS mode
 
     Notes
@@ -62,34 +76,38 @@ def launch_corba(exec_file=None, run_location=None, jobname=None, nproc=None,
 
     # can't run /BATCH in windows, so we trick it using "-b" and
     # provide a dummy input file
-    if os.name == 'nt':
+    if os.name == "nt":
         # must be a random filename to avoid conflicts with other
         # potential instances
-        tmp_file = '%s.inp' % random_string(10)
-        with open(os.path.join(run_location, tmp_file), 'w') as f:
-            f.write('FINISH')
-        additional_switches += ' -b -i %s -o out.txt' % tmp_file
+        tmp_file = "%s.inp" % random_string(10)
+        with open(os.path.join(run_location, tmp_file), "w") as f:
+            f.write("FINISH")
+        additional_switches += " -b -i %s -o out.txt" % tmp_file
 
     # command must include "aas" flag to start MAPDL server
-    command = '"%s" -aas -j %s -np %d %s' % (exec_file,
-                                             jobname,
-                                             nproc,
-                                             additional_switches)
+    command = '"%s" -aas -j %s -np %d %s' % (
+        exec_file,
+        jobname,
+        nproc,
+        additional_switches,
+    )
 
     # remove any broadcast files
-    broadcast_file = os.path.join(run_location, 'mapdl_broadcasts.txt')
+    broadcast_file = os.path.join(run_location, "mapdl_broadcasts.txt")
     if os.path.isfile(broadcast_file):
         os.remove(broadcast_file)
 
     if verbose:
-        subprocess.Popen(command, shell=True,
-                         cwd=run_location)
+        subprocess.Popen(command, shell=True, cwd=run_location)
     else:
-        subprocess.Popen(command, shell=True,
-                         cwd=run_location,
-                         stdin=subprocess.DEVNULL,
-                         stdout=subprocess.DEVNULL,
-                         stderr=subprocess.DEVNULL)
+        subprocess.Popen(
+            command,
+            shell=True,
+            cwd=run_location,
+            stdin=subprocess.DEVNULL,
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
+        )
 
     # listen for broadcast file
     telapsed = 0
@@ -100,7 +118,7 @@ def launch_corba(exec_file=None, run_location=None, jobname=None, nproc=None,
             if os.path.isfile(broadcast_file):
                 broadcast = open(broadcast_file).read()
                 # see if connection to RPC has been made
-                rpc_txt = 'visited:collaborativecosolverunitior-set:'
+                rpc_txt = "visited:collaborativecosolverunitior-set:"
                 started_rpc = rpc_txt in broadcast
 
             time.sleep(0.1)
@@ -111,14 +129,14 @@ def launch_corba(exec_file=None, run_location=None, jobname=None, nproc=None,
 
     # exit if timed out
     if not started_rpc:
-        err_str = 'Unable to start ANSYS within %.1f seconds' % start_timeout
+        err_str = "Unable to start ANSYS within %.1f seconds" % start_timeout
         if os.path.isfile(broadcast_file):
             broadcast = open(broadcast_file).read()
-            err_str += '\n\nLast broadcast:\n%s' % broadcast
+            err_str += "\n\nLast broadcast:\n%s" % broadcast
         raise TimeoutError(err_str)
 
     # return CORBA key
-    keyfile = os.path.join(run_location, 'aaS_MapdlId.txt')
+    keyfile = os.path.join(run_location, "aaS_MapdlId.txt")
     return open(keyfile).read()
 
 
@@ -140,26 +158,40 @@ class MapdlCorba(_MapdlCore):
     verbose : bool
         Print all output from MAPDL to Python.  Useful for debugging
 
+    log_file : bool, optional
+        Copy the log to a file called `logs.log` located where the
+        python script is executed. Default ``True``.
+
+    print_com : bool, optional
+        Print the command ``/COM`` arguments to the standard output.
+        Default ``False``.
     """
 
-    def __init__(self, loglevel='INFO', log_apdl='w', use_vtk=True,
+    def __init__(self, loglevel='INFO', log_apdl=None, use_vtk=True,
+                log_file = True,
                  log_broadcast=False, verbose=False, **start_parm):
         """Open a connection to MAPDL via a CORBA interface"""
         super().__init__(loglevel=loglevel, use_vtk=use_vtk, log_apdl=log_apdl,
-                         log_broadcast=False, **start_parm)
+                        log_file=log_file, log_broadcast=False,
+                        print_com=print_com, **start_parm)
+
         self._broadcast_logger = None
         self._server = None
         self._outfile = None
         self._log_broadcast = log_broadcast
         self._launch(start_parm, verbose)
-        super().__init__(loglevel=loglevel, use_vtk=use_vtk, log_apdl=log_apdl,
-                         **start_parm)
+        super().__init__(
+            loglevel=loglevel, use_vtk=use_vtk, log_apdl=log_apdl, **start_parm
+        )
 
         # critical for collection
         INSTANCES.append(weakref.ref(self))
+        self._corba_key = None
 
     def _launch(self, start_parm, verbose):
+        """Launch CORBA."""
         corba_key = launch_corba(verbose=verbose, **start_parm)
+        self._corba_key = corba_key
 
         orb = CORBA.ORB_init()
         self._server = orb.string_to_object(corba_key)
@@ -168,14 +200,15 @@ class MapdlCorba(_MapdlCore):
         try:
             self._server.getComponentName()
         except:
-            raise MapdlRuntimeError('Unable to connect to APDL server')
+            raise MapdlRuntimeError("Unable to connect to APDL server")
 
         # must set to non-interactive in linux
-        if os.name == 'posix':
+        if os.name == "posix":
             self._batch()
 
-        self._log.debug('Connected to ANSYS using CORBA interface with key %s',
-                        corba_key)
+        self._log.debug(
+            "Connected to ANSYS using CORBA interface with key %s", corba_key
+        )
 
         # separate logger for broadcast file
         if self._log_broadcast:
@@ -183,16 +216,16 @@ class MapdlCorba(_MapdlCore):
 
     @property
     def _broadcast_file(self):
-        return os.path.join(self.directory, 'mapdl_broadcasts.txt')
+        return os.path.join(self.directory, "mapdl_broadcasts.txt")
 
     @threaded
     def _start_broadcast_logger(self, update_rate=1.0):
-        """Separate logger using broadcast_file """
+        """Separate logger using broadcast_file"""
         # listen to broadcast file
         loadstep = 0
         overall_progress = 0
         try:
-            old_tail = ''
+            old_tail = ""
             old_size = 0
             while not self._exited:
                 new_size = os.path.getsize(self._broadcast_file)
@@ -200,17 +233,17 @@ class MapdlCorba(_MapdlCore):
                     old_size = new_size
                     new_tail = tail(self._broadcast_file, 4)
                     if new_tail != old_tail:
-                        lines = new_tail.split('>>')
+                        lines = new_tail.split(">>")
                         for line in lines:
-                            line = line.strip().replace('<<broadcast::', '')
+                            line = line.strip().replace("<<broadcast::", "")
                             if "current-load-step" in line:
-                                n = int(re.search(r'\d+', line).group())
+                                n = int(re.search(r"\d+", line).group())
                                 if n > loadstep:
                                     loadstep = n
                                     overall_progress = 0
                                     self._log.info(line)
                             elif "overall-progress" in line:
-                                n = int(re.search(r'\d+', line).group())
+                                n = int(re.search(r"\d+", line).group())
                                 if n > overall_progress:
                                     overall_progress = n
                                     self._log.info(line)
@@ -234,7 +267,7 @@ class MapdlCorba(_MapdlCore):
                 pass
 
             try:
-                self.run('/EXIT')
+                self.run("/EXIT")
             except:
                 pass
 
@@ -276,37 +309,37 @@ class MapdlCorba(_MapdlCore):
         """Sends a command to the mapdl server via the CORBA interface"""
         self._reset_cache()
         if self._server is None:
-            raise MapdlExitedError('ANSYS exited')
+            raise MapdlExitedError("ANSYS exited")
 
         # cleanup command
         command = command.strip()
         if not command:
-            raise ValueError('Cannot run empty command')
+            raise ValueError("Cannot run empty command")
 
-        if command[:4].lower() == 'cdre':
+        if command[:4].lower() == "cdre":
             with self.non_interactive:
                 self.run(command)
             return self._response
 
-        if command[:4].lower() == '/com':
-            split_command = command.split(',')
+        if command[:4].lower() == "/com":
+            split_command = command.split(",")
             if len(split_command) < 2:
-                return ''
+                return ""
             elif not split_command[1]:
-                return ''
+                return ""
             elif split_command[1]:
                 if not split_command[1].strip():
-                    return ''
+                    return ""
 
         # /OUTPUT not redirected properly in corba
-        if command[:4].lower() == '/out':
-            items = command.split(',')
+        if command[:4].lower() == "/out":
+            items = command.split(",")
             if len(items) > 1:  # redirect to file
                 if len(items) > 2:
                     if items[2].strip():
-                        filename = '.'.join(items[1:3]).strip()
+                        filename = ".".join(items[1:3]).strip()
                     else:
-                        filename = '.'.join(items[1:2]).strip()
+                        filename = ".".join(items[1:2]).strip()
                 else:
                     filename = items[1]
 
@@ -315,32 +348,32 @@ class MapdlCorba(_MapdlCore):
                         filename = os.path.join(self.directory, filename)
                     self._output = filename
                     if len(items) == 5:
-                        if items[4].lower().strip() == 'append':
-                            self._outfile = open(filename, 'a')
+                        if items[4].lower().strip() == "append":
+                            self._outfile = open(filename, "a")
                     else:
-                        self._outfile = open(filename, 'w')
+                        self._outfile = open(filename, "w")
                 else:
                     self._close_output()
 
             else:
                 self._close_output()
-            return ''
+            return ""
 
         # include error checking
-        text = ''
-        additional_text = ''
+        text = ""
+        additional_text = ""
 
-        self._log.debug('Running command %s', command)
+        self._log.debug("Running command %s", command)
         text = self._server.executeCommandToString(command)
 
         # print suppressed output
-        additional_text = self._server.executeCommandToString('/GO')
+        additional_text = self._server.executeCommandToString("/GO")
 
         # return text, additional_text
         if text == additional_text:
-            additional_text = ''
+            additional_text = ""
 
-        response = '%s\n%s' % (text, additional_text)
+        response = "%s\n%s" % (text, additional_text)
 
         if self._outfile is not None:
             self._outfile.write(response)
@@ -349,7 +382,14 @@ class MapdlCorba(_MapdlCore):
 
     def _close_output(self):
         """closes the output file"""
-        self._output = ''
+        self._output = ""
         if self._outfile:
             self._outfile.close()
         self._outfile = None
+
+    @property
+    def _name(self):
+        """Instance unique identifier."""
+        if hasattr(self, "_corba_key"):
+            return f"CORBA_PID_{self._corba_key}"
+        return f"CORBA_INSTANCE_{id(self)}"
