@@ -12,16 +12,18 @@ VALID_TYPE_MSG = """- 'S' : Select a new set (default)
 - 'U' : Unselect a set from the current set.
 """
 
-FLST_LOOKUP = {'NODE': 1,  # node numbers
-               'ELEM': 2,  # element numbers
-               'KP': 3,  # keypoint numbers
-               'LINE': 4,  # line numbers
-               'AREA': 5,  # area numbers
-               'VOLU': 6,  # volume numbers
-               'TRACE': 7,  # trace points
-               'COORD': 8,  # coordinate locations
+FLST_LOOKUP = {
+    "NODE": 1,  # node numbers
+    "ELEM": 2,  # element numbers
+    "KP": 3,  # keypoint numbers
+    "LINE": 4,  # line numbers
+    "AREA": 5,  # area numbers
+    "VOLU": 6,  # volume numbers
+    "TRACE": 7,  # trace points
+    "COORD": 8,  # coordinate locations
 }
 
+
 def merge_polydata(items):
     """Merge list of polydata or unstructured grids"""
 
@@ -69,19 +71,19 @@ def get_elements_per_area(resp):
 
     """
     # MAPDL changed their output at some point.  Check for both output types.
-    reg = re.compile(r'Meshing of area (\d*) completed \*\* (\d*) elements')
+    reg = re.compile(r"Meshing of area (\d*) completed \*\* (\d*) elements")
     groups = reg.findall(resp)
     if groups:
         groups = [[int(anum), int(nelem)] for anum, nelem in groups]
     else:
-        reg = re.compile(r'AREA\s*(\d*).*?(\d*)\s*QUADRILATERALS,\s*(\d*) TRIANGLES')
+        reg = re.compile(r"AREA\s*(\d*).*?(\d*)\s*QUADRILATERALS,\s*(\d*) TRIANGLES")
         groups = reg.findall(resp)
         groups = [(int(anum), int(nquad) + int(ntri)) for anum, nquad, ntri in groups]
 
     return groups
 
 
-class Geometry():
+class Geometry:
     """Pythonic representation of MAPDL CAD geometry
 
     Contains advanced methods to extend geometry building and
@@ -91,8 +93,9 @@ class Geometry():
 
     def __init__(self, mapdl):
         from ansys.mapdl.core.mapdl import _MapdlCore
+
         if not isinstance(mapdl, _MapdlCore):
-            raise TypeError('Must be initialized using a MAPDL class')
+            raise TypeError("Must be initialized using a MAPDL class")
 
         self._mapdl = mapdl
         self._keypoints_cache = None
@@ -109,8 +112,9 @@ class Geometry():
         try:
             from pyiges import Iges
         except ImportError:
-            raise ImportError('Please install pyiges to use this feature with:\n'
-                              'pip install pyiges')
+            raise ImportError(
+                "Please install pyiges to use this feature with:\n" "pip install pyiges"
+            )
         return Iges(self._mapdl._generate_iges())
 
     def _reset_cache(self):
@@ -157,7 +161,7 @@ class Geometry():
 
         Returns
         -------
-        areas : list, pyvista.UnstructuredGrid
+        list of pyvista.UnstructuredGrid
             List of ``pyvista.UnstructuredGrid`` meshes representing
             the active surface areas selected by ``ASEL``.  If
             ``merge=True``, areas are returned as a single merged
@@ -201,12 +205,12 @@ class Geometry():
         """
         quality = int(quality)
         if quality > 10:
-            raise ValueError('``quality`` parameter must be a value between 0 and 10')
+            raise ValueError("``quality`` parameter must be a value between 0 and 10")
         surf = self.generate_surface(11 - quality)
         if merge:
             return surf
 
-        entity_num = surf['entity_num']
+        entity_num = surf["entity_num"]
         areas = []
         anums = np.unique(entity_num)
         for anum in anums:
@@ -237,58 +241,54 @@ class Geometry():
             Steps to between amin and amax.
         """
         # store initially selected areas and elements
-        with self._mapdl.chain_commands:
-            self._mapdl.cm('__tmp_elem__', 'ELEM')
-            self._mapdl.cm('__tmp_area__', 'AREA')
+        with self._mapdl.non_interactive:
+            self._mapdl.cm("__tmp_elem__", "ELEM")
+            self._mapdl.cm("__tmp_area__", "AREA")
         orig_anum = self.anum
 
         # reselect from existing selection to mimic APDL behavior
         if amin or amax:
             if amax is None:
                 amax = amin
-            else:
-                amax = ''
 
             if amin is None:  # amax is non-zero
                 amin = 1
 
             if ninc is None:
-                ninc = ''
+                ninc = ""
 
-            self._mapdl.asel('R', 'AREA', vmin=amin, vmax=amax, vinc=ninc)
+            self._mapdl.asel("R", "AREA", vmin=amin, vmax=amax, vinc=ninc)
 
         # duplicate areas to avoid affecting existing areas
-        a_num = int(self._mapdl.get(entity='AREA', item1='NUM', it1num='MAXD'))
-        with self._mapdl.chain_commands:
-            self._mapdl.numstr('AREA', a_num)
-            self._mapdl.agen(2, 'ALL', noelem=1)
-        a_max = int(self._mapdl.get(entity='AREA', item1='NUM', it1num='MAXD'))
+        a_num = int(self._mapdl.get(entity="AREA", item1="NUM", it1num="MAXD"))
+        self._mapdl.numstr("AREA", a_num, mute=True)
+        self._mapdl.agen(2, "ALL", noelem=1, mute=True)
+        a_max = int(self._mapdl.get(entity="AREA", item1="NUM", it1num="MAXD"))
 
-        with self._mapdl.chain_commands:
-            self._mapdl.asel('S', 'AREA', vmin=a_num + 1, vmax=a_max)
-            self._mapdl.aatt()  # necessary to reset element/area meshing association
+        self._mapdl.asel("S", "AREA", vmin=a_num + 1, vmax=a_max, mute=True)
+        # necessary to reset element/area meshing association
+        self._mapdl.aatt(mute=True)
 
         # create a temporary etype
-        etype_max = int(self._mapdl.get(entity='ETYP', item1='NUM', it1num='MAX'))
+        etype_max = int(self._mapdl.get(entity="ETYP", item1="NUM", it1num="MAX"))
         etype_old = self._mapdl.parameters.type
         etype_tmp = etype_max + 1
 
         old_routine = self._mapdl.parameters.routine
 
-        with self._mapdl.chain_commands:
-            self._mapdl.et(etype_tmp, 'MESH200', 6)
-            self._mapdl.shpp('off')
-            self._mapdl.smrtsize(density)
-            self._mapdl.type(etype_tmp)
+        self._mapdl.et(etype_tmp, "MESH200", 6, mute=True)
+        self._mapdl.shpp("off", mute=True)
+        self._mapdl.smrtsize(density, mute=True)
+        self._mapdl.type(etype_tmp, mute=True)
 
-            if old_routine != 'PREP7':
-                self._mapdl.prep7()
+        if old_routine != "PREP7":
+            self._mapdl.prep7(mute=True)
 
         # Mesh and get the number of elements per area
-        resp = self._mapdl.amesh('all')
+        resp = self._mapdl.amesh("all")
         groups = get_elements_per_area(resp)
 
-        self._mapdl.esla('S')
+        self._mapdl.esla("S")
         grid = self._mapdl.mesh._grid.linear_copy()
         pd = pv.PolyData(grid.points, grid.cells, n_faces=grid.n_cells)
 
@@ -297,20 +297,15 @@ class Geometry():
         # pd.clean(inplace=True)  # OPTIONAL
 
         # delete all temporary meshes and clean up settings
-        with self._mapdl.chain_commands:
-            self._mapdl.aclear('ALL')
-            self._mapdl.adele('ALL', kswp=1)
-            self._mapdl.numstr('AREA', 1)
-            self._mapdl.type(etype_old)
-            self._mapdl.etdele(etype_tmp)
-            self._mapdl.shpp('ON')
-            self._mapdl.smrtsize('OFF')
-            self._mapdl.cmsel('S', '__tmp_area__', 'AREA')
-            self._mapdl.cmsel('S', '__tmp_elem__', 'ELEM')
-
-        # ensure the number of groups matches the number of areas
-        if len(groups) != len(orig_anum):
-            groups = None
+        self._mapdl.aclear("ALL", mute=True)
+        self._mapdl.adele("ALL", kswp=1, mute=True)
+        self._mapdl.numstr("AREA", 1, mute=True)
+        self._mapdl.type(etype_old, mute=True)
+        self._mapdl.etdele(etype_tmp, mute=True)
+        self._mapdl.shpp("ON", mute=True)
+        self._mapdl.smrtsize("OFF", mute=True)
+        self._mapdl.cmsel("S", "__tmp_area__", "AREA", mute=True)
+        self._mapdl.cmsel("S", "__tmp_elem__", "ELEM", mute=True)
 
         # store the area number used for each element
         entity_num = np.empty(grid.n_cells, dtype=np.int32)
@@ -320,12 +315,12 @@ class Geometry():
             for index, (anum, nelem) in enumerate(groups):
                 # have to use original area numbering here as the
                 # duplicated areas numbers are inaccurate
-                entity_num[i:i+nelem] = orig_anum[index]
+                entity_num[i : i + nelem] = orig_anum[index]
                 i += nelem
         else:
             entity_num[:] = 0
 
-        pd['entity_num'] = entity_num
+        pd["entity_num"] = entity_num
         return pd
 
     @property
@@ -337,7 +332,7 @@ class Geometry():
         >>> mapdl.n_area
         1
         """
-        return self._item_count('VOLU')
+        return self._item_count("VOLU")
 
     @property
     def n_area(self):
@@ -348,7 +343,7 @@ class Geometry():
         >>> mapdl.n_area
         1
         """
-        return self._item_count('AREA')
+        return self._item_count("AREA")
 
     @property
     def n_line(self):
@@ -359,7 +354,7 @@ class Geometry():
         >>> mapdl.n_line
         1
         """
-        return self._item_count('LINE')
+        return self._item_count("LINE")
 
     @property
     def n_keypoint(self):
@@ -370,12 +365,12 @@ class Geometry():
         >>> mapdl.n_keypoint
         1
         """
-        return self._item_count('KP')
+        return self._item_count("KP")
 
     @supress_logging
     def _item_count(self, entity):
         """Return item count for a given entity"""
-        return int(self._mapdl.get(entity=entity, item1='COUNT'))
+        return int(self._mapdl.get(entity=entity, item1="COUNT"))
 
     @property
     def knum(self):
@@ -387,7 +382,7 @@ class Geometry():
         >>> mapdl.knum
         array([1, 2, 3, 4, 5, 6, 7, 8], dtype=int32)
         """
-        return self._mapdl.get_array('KP', item1='KLIST').astype(np.int32)    
+        return self._mapdl.get_array("KP", item1="KLIST").astype(np.int32)
 
     @property
     def lnum(self):
@@ -401,7 +396,7 @@ class Geometry():
         """
         # this (weirdly) sometimes fails
         for _ in range(5):
-            lnum = self._mapdl.get_array('LINES', item1='LLIST')
+            lnum = self._mapdl.get_array("LINES", item1="LLIST")
             if lnum.size == self.n_line:
                 break
         return lnum.astype(np.int32)
@@ -409,13 +404,14 @@ class Geometry():
     @property
     def anum(self):
         """Array of area numbers.
+
         Examples
         --------
         >>> mapdl.block(0, 1, 0, 1, 0, 1)
         >>> mapdl.anum
         array([1, 2, 3, 4, 5, 6], dtype=int32)
         """
-        return self._mapdl.get_array('AREA', item1='ALIST').astype(np.int32)
+        return self._mapdl.get_array("AREA", item1="ALIST").astype(np.int32)
 
     @property
     def vnum(self):
@@ -427,56 +423,54 @@ class Geometry():
         >>> mapdl.vnum
         array([1], dtype=int32)
         """
-        return self._mapdl.get_array('VOLU', item1='VLIST').astype(np.int32)
+        return self._mapdl.get_array("VOLU", item1="VLIST").astype(np.int32)
 
     @supress_logging
     def _load_lines(self):
         """Load lines from MAPDL using IGES"""
         # ignore volumes
-        with self._mapdl.chain_commands:
-            self._mapdl.cm('__tmp_volu__', 'VOLU')
-            self._mapdl.cm('__tmp_line__', 'LINE')
-            self._mapdl.cm('__tmp_area__', 'AREA')
-            self._mapdl.cm('__tmp_keyp__', 'KP')
-            self._mapdl.ksel('ALL')
-            self._mapdl.lsel('ALL')
-            self._mapdl.asel('ALL')
-            self._mapdl.vsel('NONE')
+        self._mapdl.cm("__tmp_volu__", "VOLU", mute=True)
+        self._mapdl.cm("__tmp_line__", "LINE", mute=True)
+        self._mapdl.cm("__tmp_area__", "AREA", mute=True)
+        self._mapdl.cm("__tmp_keyp__", "KP", mute=True)
+        self._mapdl.ksel("ALL", mute=True)
+        self._mapdl.lsel("ALL", mute=True)
+        self._mapdl.asel("ALL", mute=True)
+        self._mapdl.vsel("NONE", mute=True)
 
         iges = self._load_iges()
 
-        with self._mapdl.chain_commands:
-            self._mapdl.cmsel('S', '__tmp_volu__', 'VOLU')
-            self._mapdl.cmsel('S', '__tmp_area__', 'AREA')
-            self._mapdl.cmsel('S', '__tmp_line__', 'LINE')
-            self._mapdl.cmsel('S', '__tmp_keyp__', 'KP')
+        self._mapdl.cmsel("S", "__tmp_volu__", "VOLU", mute=True)
+        self._mapdl.cmsel("S", "__tmp_area__", "AREA", mute=True)
+        self._mapdl.cmsel("S", "__tmp_line__", "LINE", mute=True)
+        self._mapdl.cmsel("S", "__tmp_keyp__", "KP", mute=True)
 
         selected_lnum = self.lnum
         lines = []
         entity_nums = []
         for bspline in iges.bsplines():
             # allow only 10001 as others appear to be construction entities
-            if bspline.d['status_number'] in [1, 10001]:
-                entity_num = int(bspline.d['entity_subs_num'])
+            if bspline.d["status_number"] in [1, 10001]:
+                entity_num = int(bspline.d["entity_subs_num"])
                 if entity_num not in entity_nums and entity_num in selected_lnum:
                     entity_nums.append(entity_num)
                     line = bspline.to_vtk()
-                    line.cell_arrays['entity_num'] = entity_num
+                    line.cell_data["entity_num"] = entity_num
                     lines.append(line)
 
         entities = iges.lines() + iges.circular_arcs()
         for line in entities:
-            if line.d['status_number'] == 1:
-                entity_num = int(line.d['entity_subs_num'])
+            if line.d["status_number"] == 1:
+                entity_num = int(line.d["entity_subs_num"])
                 if entity_num not in entity_nums and entity_num in selected_lnum:
                     entity_nums.append(entity_num)
                     line = line.to_vtk(resolution=100)
-                    line.cell_arrays['entity_num'] = entity_num
+                    line.cell_data["entity_num"] = entity_num
                     lines.append(line)
 
         if lines:
             lines = merge_polydata(lines)
-            lines['entity_num'] = lines['entity_num'].astype(np.int32)
+            lines["entity_num"] = lines["entity_num"].astype(np.int32)
         else:
             lines = pv.PolyData()
 
@@ -485,42 +479,40 @@ class Geometry():
     def _load_keypoints(self):
         """Load keypoints from MAPDL using IGES"""
         # write only keypoints
-        with self._mapdl.chain_commands:
-            self._mapdl.cm('__tmp_volu__', 'VOLU')
-            self._mapdl.cm('__tmp_area__', 'AREA')
-            self._mapdl.cm('__tmp_line__', 'LINE')
-            self._mapdl.vsel('NONE')
-            self._mapdl.asel('NONE')
-            self._mapdl.lsel('NONE')
+        self._mapdl.cm("__tmp_volu__", "VOLU", mute=True)
+        self._mapdl.cm("__tmp_area__", "AREA", mute=True)
+        self._mapdl.cm("__tmp_line__", "LINE", mute=True)
+        self._mapdl.vsel("NONE", mute=True)
+        self._mapdl.asel("NONE", mute=True)
+        self._mapdl.lsel("NONE", mute=True)
 
         iges = self._load_iges()
 
-        with self._mapdl.chain_commands:
-            self._mapdl.cmsel('S', '__tmp_volu__', 'VOLU')
-            self._mapdl.cmsel('S', '__tmp_area__', 'AREA')
-            self._mapdl.cmsel('S', '__tmp_line__', 'LINE')
+        self._mapdl.cmsel("S", "__tmp_volu__", "VOLU", mute=True)
+        self._mapdl.cmsel("S", "__tmp_area__", "AREA", mute=True)
+        self._mapdl.cmsel("S", "__tmp_line__", "LINE", mute=True)
 
         keypoints = []
         kp_num = []
         for kp in iges.points():
             keypoints.append([kp.x, kp.y, kp.z])
-            kp_num.append(int(kp.d['entity_subs_num']))
+            kp_num.append(int(kp.d["entity_subs_num"]))
 
         # self._kp_num = np.array(self._kp_num)
         keypoints_pd = pv.PolyData(keypoints)
-        keypoints_pd['entity_num'] = kp_num
+        keypoints_pd["entity_num"] = kp_num
         return keypoints_pd
 
     def __str__(self):
         """Current geometry info"""
-        info = 'MAPDL Selected Geometry\n'
-        info += 'Keypoints:  %d\n' % self.n_keypoint
-        info += 'Lines:      %d\n' % self.n_line
-        info += 'Areas:      %d\n' % self.n_area
-        info += 'Volumes:    %d\n' % self.n_volu
+        info = "MAPDL Selected Geometry\n"
+        info += "Keypoints:  %d\n" % self.n_keypoint
+        info += "Lines:      %d\n" % self.n_line
+        info += "Areas:      %d\n" % self.n_area
+        info += "Volumes:    %d\n" % self.n_volu
         return info
 
-    def keypoint_select(self, items, sel_type='S', return_selected=False):
+    def keypoint_select(self, items, sel_type="S", return_selected=False):
         """Select keypoints using a sequence of items.
 
         Parameters
@@ -582,22 +574,22 @@ class Geometry():
             items = items.upper()
 
         # special cases
-        if items is None or items == 'NONE':
-            self._mapdl.ksel('NONE')
+        if items is None or items == "NONE":
+            self._mapdl.ksel("NONE")
             return
 
-        if items == 'ALL':
-            self._mapdl.ksel('ALL')
+        if items == "ALL":
+            self._mapdl.ksel("ALL")
             if return_selected:
                 return self.knum
             return
 
-        self._select_items(items, 'KP', sel_type)
+        self._select_items(items, "KP", sel_type)
 
         if return_selected:
             return self.knum
 
-    def line_select(self, items, sel_type='S', return_selected=False):
+    def line_select(self, items, sel_type="S", return_selected=False):
         """Select lines using a sequence of items.
 
         Parameters
@@ -621,6 +613,8 @@ class Geometry():
 
         Returns
         -------
+        list
+            List of the selected lines if ``return_selected=True``.
 
         Examples
         --------
@@ -657,22 +651,22 @@ class Geometry():
             items = items.upper()
 
         # special cases
-        if items is None or items == 'NONE':
-            self._mapdl.lsel('NONE')
+        if items is None or items == "NONE":
+            self._mapdl.lsel("NONE")
             return
 
-        if items == 'ALL':
-            self._mapdl.lsel('ALL')
+        if items == "ALL":
+            self._mapdl.lsel("ALL")
             if return_selected:
                 return self.lnum
             return
 
-        self._select_items(items, 'LINE', sel_type)
+        self._select_items(items, "LINE", sel_type)
 
         if return_selected:
             return self.lnum
 
-    def area_select(self, items, sel_type='S', return_selected=False):
+    def area_select(self, items, sel_type="S", return_selected=False):
         """Select areas using a sequence of items.
 
         Parameters
@@ -696,6 +690,8 @@ class Geometry():
 
         Returns
         -------
+        list
+            List of the selected areas if ``return_selected=True``.
 
         Examples
         --------
@@ -732,22 +728,22 @@ class Geometry():
             items = items.upper()
 
         # special cases
-        if items is None or items == 'NONE':
-            self._mapdl.asel('NONE')
+        if items is None or items == "NONE":
+            self._mapdl.asel("NONE")
             return
 
-        if items == 'ALL':
-            self._mapdl.asel('ALL')
+        if items == "ALL":
+            self._mapdl.asel("ALL")
             if return_selected:
                 return self.anum
             return
 
-        self._select_items(items, 'AREA', sel_type)
+        self._select_items(items, "AREA", sel_type)
 
         if return_selected:
             return self.anum
 
-    def volume_select(self, items, sel_type='S', return_selected=False):
+    def volume_select(self, items, sel_type="S", return_selected=False):
         """Select volumes using a sequence of items.
 
         Parameters
@@ -771,6 +767,8 @@ class Geometry():
 
         Returns
         -------
+        list
+            List of the selected volumes if ``return_selected=True``.
 
         Examples
         --------
@@ -807,17 +805,17 @@ class Geometry():
             items = items.upper()
 
         # special cases
-        if items is None or items == 'NONE':
-            self._mapdl.vsel('NONE')
+        if items is None or items == "NONE":
+            self._mapdl.vsel("NONE")
             return
 
-        if items == 'ALL':
-            self._mapdl.vsel('ALL')
+        if items == "ALL":
+            self._mapdl.vsel("ALL")
             if return_selected:
                 return self.vnum
             return
 
-        self._select_items(items, 'VOLU', sel_type)
+        self._select_items(items, "VOLU", sel_type)
 
         if return_selected:
             return self.vnum
@@ -855,15 +853,17 @@ class Geometry():
             raise KeyError(f'Invalid ``item_type`` "{item_type}"')
 
         sel_type = sel_type.upper()
-        valid_sel_type = ['S', 'R', 'A', 'U']
+        valid_sel_type = ["S", "R", "A", "U"]
         if sel_type not in valid_sel_type:
-            raise ValueError(f'Invalid ``sel_type`` "{sel_type}"\n\n'
-                             f'Use one of the following:\n{VALID_TYPE_MSG}')
+            raise ValueError(
+                f'Invalid ``sel_type`` "{sel_type}"\n\n'
+                f"Use one of the following:\n{VALID_TYPE_MSG}"
+            )
 
         # convert to a flat array as it's easier for type checking
         items = np.asarray(items)
         if not np.issubdtype(items.dtype, np.number):
-            raise TypeError('Item numbers must be a numeric type')
+            raise TypeError("Item numbers must be a numeric type")
         items = items.ravel().astype(np.int, copy=False)
 
         # consider logic for negative values to support ranges.  This
@@ -875,22 +875,22 @@ class Geometry():
         # LSEL, , , ,P51X
 
         # unordered option
-        with self._mapdl.chain_commands:
+        with self._mapdl.non_interactive:
             self._mapdl.flst(5, items.size, FLST_LOOKUP[item_type])
             for item in items:
                 self._mapdl.fitem(5, item)
 
-            if item_type == 'NODE':
-                self._mapdl.nsel(sel_type, vmin='P51X')
-            elif item_type == 'ELEM':
-                self._mapdl.esel(sel_type, vmin='P51X')
-            elif item_type == 'KP':
-                self._mapdl.ksel(sel_type, vmin='P51X')
-            elif item_type == 'LINE':
-                self._mapdl.lsel(sel_type, vmin='P51X')
-            elif item_type == 'AREA':
-                self._mapdl.asel(sel_type, vmin='P51X')
-            elif item_type == 'VOLU':
-                self._mapdl.vsel(sel_type, vmin='P51X')
+            if item_type == "NODE":
+                self._mapdl.nsel(sel_type, vmin="P51X")
+            elif item_type == "ELEM":
+                self._mapdl.esel(sel_type, vmin="P51X")
+            elif item_type == "KP":
+                self._mapdl.ksel(sel_type, vmin="P51X")
+            elif item_type == "LINE":
+                self._mapdl.lsel(sel_type, vmin="P51X")
+            elif item_type == "AREA":
+                self._mapdl.asel(sel_type, vmin="P51X")
+            elif item_type == "VOLU":
+                self._mapdl.vsel(sel_type, vmin="P51X")
             else:
                 raise ValueError(f'Unable to select "{item_type}"')
