@@ -6,31 +6,47 @@ from ansys.mapdl.core.misc import unique_rows
 from .theme import MapdlTheme
 
 
-def general_plotter(meshes, points, labels,
-                    title='',
-                    cpos=None,
-                    show_bounds=False, show_axes=True,
-                    background=None, off_screen=None,
-                    savefig=None,
-                    window_size=None,
-                    notebook=None,
-                    # add_mesh kwargs:
-                    style=None,
-                    color='w',
-                    show_edges=None, edge_color=None, point_size=5.0,
-                    line_width=None, opacity=1.0, flip_scalars=False,
-                    lighting=None, n_colors=256,
-                    interpolate_before_map=True, cmap=None,
-                    render_points_as_spheres=False, render_lines_as_tubes=False,
-                    scalar_bar_args={},
-                    smooth_shading=None,
-                    show_scalar_bar=None,
-                    # labels kwargs
-                    font_size=None,
-                    font_family=None,
-                    text_color=None,
-                    theme=None,
-                    return_plotter=False):
+def general_plotter(
+    meshes,
+    points,
+    labels,
+    title="",
+    cpos=None,
+    show_bounds=False,
+    show_axes=True,
+    background=None,
+    off_screen=None,
+    savefig=None,
+    window_size=None,
+    notebook=None,
+    # add_mesh kwargs:
+    style=None,
+    color="w",
+    show_edges=None,
+    edge_color=None,
+    point_size=5.0,
+    line_width=None,
+    opacity=1.0,
+    flip_scalars=False,
+    lighting=None,
+    n_colors=256,
+    interpolate_before_map=True,
+    cmap=None,
+    render_points_as_spheres=False,
+    render_lines_as_tubes=False,
+    scalar_bar_args={},
+    smooth_shading=None,
+    split_sharp_edges=None,
+    feature_angle=30.0,
+    show_scalar_bar=None,
+    # labels kwargs
+    font_size=None,
+    font_family=None,
+    text_color=None,
+    theme=None,
+    return_plotter=False,
+    return_cpos=False,
+):
     """General pymapdl plotter for APDL geometry and meshes.
 
     Parameters
@@ -138,6 +154,18 @@ def general_plotter(meshes, points, labels,
         Smoothly render curved surfaces when plotting.  Not helpful
         for all meshes.
 
+    split_sharp_edge : bool, optional
+        Split sharp edges exceeding 30 degrees when plotting with
+        smooth shading.  Control the angle with the optional
+        keyword argument ``feature_angle``.
+        By default this is ``False``.
+
+        .. note:: Note that enabling this will create a copy of
+        the input mesh within the plotter.
+
+    feature_angle : float, optional
+        Angle to consider an edge a sharp edge. Default 30 degrees.
+
     theme : pyvista.DefaultTheme, optional
         PyVista theme.  Defaults to PyMAPDL theme.
 
@@ -145,6 +173,9 @@ def general_plotter(meshes, points, labels,
         Return the plotting object rather than showing the plot and
         returning the camera position.  Default ``False``.
 
+    return_cpos : bool, optional
+        Returns the camera position as an array. Default ``False``.
+
     Returns
     -------
     cpos or pyvista.Plotter
@@ -188,44 +219,63 @@ def general_plotter(meshes, points, labels,
         pl.set_background(background)
 
     for point in points:
-        pl.add_points(point['points'],
-                      scalars=point.get('scalars', None),
-                      color=color,
-                      show_edges=show_edges, edge_color=edge_color,
-                      point_size=point_size, line_width=line_width,
-                      opacity=opacity, flip_scalars=flip_scalars,
-                      lighting=lighting, n_colors=n_colors,
-                      interpolate_before_map=interpolate_before_map,
-                      cmap=cmap, render_points_as_spheres=render_points_as_spheres,
-                      render_lines_as_tubes=render_lines_as_tubes)
+        pl.add_points(
+            point["points"],
+            scalars=point.get("scalars", None),
+            color=color,
+            show_edges=show_edges,
+            edge_color=edge_color,
+            point_size=point_size,
+            line_width=line_width,
+            opacity=opacity,
+            flip_scalars=flip_scalars,
+            lighting=lighting,
+            n_colors=n_colors,
+            interpolate_before_map=interpolate_before_map,
+            cmap=cmap,
+            render_points_as_spheres=render_points_as_spheres,
+            render_lines_as_tubes=render_lines_as_tubes,
+        )
 
     for mesh in meshes:
-        pl.add_mesh(mesh['mesh'],
-                    scalars=mesh.get('scalars'),
-                    scalar_bar_args=scalar_bar_args,
-                    color=mesh.get('color', color),
-                    style=mesh.get('style', style),
-                    show_edges=show_edges, edge_color=edge_color,
-                    smooth_shading=smooth_shading,
-                    point_size=point_size, line_width=line_width,
-                    show_scalar_bar=show_scalar_bar,
-                    opacity=opacity, flip_scalars=flip_scalars,
-                    lighting=lighting, n_colors=n_colors,
-                    interpolate_before_map=interpolate_before_map,
-                    cmap=cmap, render_points_as_spheres=render_points_as_spheres,
-                    render_lines_as_tubes=render_lines_as_tubes)
+        pl.add_mesh(
+            mesh["mesh"],
+            scalars=mesh.get("scalars"),
+            scalar_bar_args=scalar_bar_args,
+            color=mesh.get("color", color),
+            style=mesh.get("style", style),
+            show_edges=show_edges,
+            edge_color=edge_color,
+            smooth_shading=smooth_shading,
+            split_sharp_edges=split_sharp_edges,
+            feature_angle=feature_angle,
+            point_size=point_size,
+            line_width=line_width,
+            show_scalar_bar=show_scalar_bar,
+            opacity=opacity,
+            flip_scalars=flip_scalars,
+            lighting=lighting,
+            n_colors=n_colors,
+            interpolate_before_map=interpolate_before_map,
+            cmap=cmap,
+            render_points_as_spheres=render_points_as_spheres,
+            render_lines_as_tubes=render_lines_as_tubes,
+        )
 
     for label in labels:
         # verify points are not duplicates
-        points, idx, _ = unique_rows(np.array(label['points']))
-        labels = np.array(label['labels'])[idx].tolist()
+        points, idx, _ = unique_rows(np.array(label["points"]))
+        labels = np.array(label["labels"])[idx].tolist()
 
-        pl.add_point_labels(points,
-                            labels,
-                            show_points=False, shadow=False,
-                            font_size=font_size,
-                            font_family=font_family,
-                            text_color=text_color)
+        pl.add_point_labels(
+            points,
+            labels,
+            show_points=False,
+            shadow=False,
+            font_size=font_size,
+            font_family=font_family,
+            text_color=text_color,
+        )
 
     if cpos:
         pl.camera_position = cpos
@@ -238,22 +288,40 @@ def general_plotter(meshes, points, labels,
     if title:
         pl.add_title(title)
 
+    def return_from_plotter():
+        returns_parameter = []
+        if return_plotter:
+            returns_parameter.append(pl)
+        if return_cpos:
+            returns_parameter.append(pl.camera_position)
+
+        if not returns_parameter:
+            returns_parameter = None
+        else:
+            if len(returns_parameter) == 1:
+                returns_parameter = returns_parameter[0]
+            else:
+                returns_parameter = tuple(returns_parameter)
+        return returns_parameter
+
+    returns_parameter = return_from_plotter()
+
     # permit user to save the figure as a screenshot
     if savefig:
-        pl.show(title=title, auto_close=False, window_size=window_size,
-                screenshot=True)
+        pl.show(title=title, auto_close=False, window_size=window_size, screenshot=True)
         pl.screenshot(savefig)
 
         # return unclosed plotter
-        if return_plotter:
-            return pl
+        if returns_parameter:
+            return returns_parameter
 
         # if not returning plotter, close right away
         pl.close()
 
-    elif return_plotter:
-        return pl
     else:
         pl.show()
 
-    return pl.camera_position
+    # Recreating "returns" to update cpos
+    returns_parameter = return_from_plotter()
+
+    return returns_parameter
