@@ -1,23 +1,24 @@
 """This module is for threaded implementations of the mapdl interface"""
+
+from ansys.mapdl.core import LOG
+
 import shutil
 import warnings
 import os
 import time
-import logging
 
 from tqdm import tqdm
 
-from ansys.mapdl.core import launch_mapdl
+from ansys.mapdl.core import launch_mapdl, get_ansys_path
 from ansys.mapdl.core.misc import threaded
 from ansys.mapdl.core.misc import create_temp_dir, threaded_daemon
-from ansys.mapdl.core.launcher import (port_in_use,
-                                       MAPDL_DEFAULT_PORT,
-                                       _version_from_path)
+from ansys.mapdl.core.launcher import (
+    port_in_use,
+    MAPDL_DEFAULT_PORT,
+    _version_from_path,
+)
 from ansys.mapdl.core.errors import VersionError
 
-LOG = logging.getLogger(__name__)
-LOG.setLevel('DEBUG')
-
 
 def available_ports(n_ports, starting_port=MAPDL_DEFAULT_PORT):
     """Return a list the first ``n_ports`` ports starting from ``starting_port``"""
@@ -30,8 +31,10 @@ def available_ports(n_ports, starting_port=MAPDL_DEFAULT_PORT):
         port += 1
 
     if len(ports) < n_ports:
-        raise RuntimeError('There are not %d available ports between %d and 65536'
-                           % (n_ports, starting_port))
+        raise RuntimeError(
+            "There are not %d available ports between %d and 65536"
+            % (n_ports, starting_port)
+        )
 
     return ports
 
@@ -82,7 +85,7 @@ class LocalMapdlPool:
 
     >>> from ansys.mapdl import LocalMapdlPool
     >>> pool = mapdl.LocalMapdlPool(10)
-    Creating Pool: 100%|████████| 10/10 [00:01<00:00,  1.43it/s]
+    Creating Pool: 100%|########| 10/10 [00:01<00:00,  1.43it/s]
 
     Create several instances with 1 CPU each running at the current
     directory within their own isolated directories.
@@ -90,44 +93,54 @@ class LocalMapdlPool:
     >>> import os
     >>> my_path = os.getcmd()
     >>> pool = mapdl.LocalMapdlPool(10, nproc=1, run_location=my_path)
-    Creating Pool: 100%|████████| 10/10 [00:01<00:00,  1.43it/s]
+    Creating Pool: 100%|########| 10/10 [00:01<00:00,  1.43it/s]
 
     Create a pool while specifying the MAPDL executable in Windows.
 
     >>> exec_file = 'C:/Program Files/ANSYS Inc/v212/ansys/bin/win64/ANSYS212.exe'
     >>> pool = mapdl.LocalMapdlPool(10, exec_file=exec_file)
-    Creating Pool: 100%|████████| 10/10 [00:01<00:00,  1.43it/s]
+    Creating Pool: 100%|########| 10/10 [00:01<00:00,  1.43it/s]
 
     Create a pool while specifying the MAPDL executable in Linux.
 
     >>> exec_file = '/ansys_inc/v211/ansys/bin/ansys211'
     >>> pool = mapdl.LocalMapdlPool(10, exec_file=exec_file)
-    Creating Pool: 100%|████████| 10/10 [00:01<00:00,  1.43it/s]
+    Creating Pool: 100%|########| 10/10 [00:01<00:00,  1.43it/s]
 
     """
 
-    def __init__(self, n_instances, wait=True, run_location=None,
-                 port=MAPDL_DEFAULT_PORT, progress_bar=True, restart_failed=True,
-                 remove_temp_files=True, **kwargs):
+    def __init__(
+        self,
+        n_instances,
+        wait=True,
+        run_location=None,
+        port=MAPDL_DEFAULT_PORT,
+        progress_bar=True,
+        restart_failed=True,
+        remove_temp_files=True,
+        **kwargs,
+    ):
         """Initialize several instances of mapdl"""
         self._instances = []
         self._root_dir = run_location
-        kwargs['remove_temp_files'] = remove_temp_files
-        kwargs['mode'] = 'grpc'
+        kwargs["remove_temp_files"] = remove_temp_files
+        kwargs["mode"] = "grpc"
         self._spawn_kwargs = kwargs
 
         # verify that mapdl is 2021R1 or newer
-        if 'exec_file' in kwargs:
-            exec_file = kwargs['exec_file']
+        if "exec_file" in kwargs:
+            exec_file = kwargs["exec_file"]
         else:  # get default executable
             exec_file = get_ansys_path()
             if exec_file is None:
-                raise FileNotFoundError('Invalid exec_file path or cannot load cached '
-                                        'ansys path.  Enter one manually using '
-                                        'exec_file=<path to executable>')
+                raise FileNotFoundError(
+                    "Invalid exec_file path or cannot load cached "
+                    "ansys path.  Enter one manually using "
+                    "exec_file=<path to executable>"
+                )
 
         if _version_from_path(exec_file) < 211:
-            raise VersionError('LocalMapdlPool requires MAPDL 2021R1 or later.')
+            raise VersionError("LocalMapdlPool requires MAPDL 2021R1 or later.")
 
         # grab available ports
         ports = available_ports(n_instances, port)
@@ -141,40 +154,49 @@ class LocalMapdlPool:
 
         n_instances = int(n_instances)
         if n_instances < 2:
-            raise ValueError('Must request at least 2 instances to create a pool.')
+            raise ValueError("Must request at least 2 instances to create a pool.")
 
         pbar = None
         if wait and progress_bar:
-            pbar = tqdm(total=n_instances, desc='Creating Pool')
+            pbar = tqdm(total=n_instances, desc="Creating Pool")
 
         # initialize a list of dummy instances
         self._instances = [None for _ in range(n_instances)]
 
         # threaded spawn
-        threads = [self._spawn_mapdl(i, ports[i], pbar) for i in range(n_instances)]
+        threads = [self._spawn_mapdl(i, ports[i], pbar, name=f'Instance {i}') for i in range(n_instances)]
         if wait:
             [thread.join() for thread in threads]
 
             # check if all clients connected have connected
             if len(self) != n_instances:
                 n_connected = len(self)
-                warnings.warn(f'Only %d clients connected out of %d requested' %
-                              (n_connected, n_instances))
+                warnings.warn(
+                    f"Only %d clients connected out of %d requested"
+                    % (n_connected, n_instances)
+                )
             if pbar is not None:
                 pbar.close()
 
         # monitor pool if requested
         if restart_failed:
-            self._pool_monitor_thread = self._monitor_pool()
+            self._pool_monitor_thread = self._monitor_pool(name='Monitoring_Thread')
 
         self._verify_unique_ports()
 
     def _verify_unique_ports(self):
         if len(self._ports) != len(self):
-            raise RuntimeError('MAPDLPool has overlapping ports')
+            raise RuntimeError("MAPDLPool has overlapping ports")
 
-    def map(self, func, iterable=None, progress_bar=True,
-            close_when_finished=False, timeout=None, wait=True):
+    def map(
+        self,
+        func,
+        iterable=None,
+        progress_bar=True,
+        close_when_finished=False,
+        timeout=None,
+        wait=True,
+    ):
         """Run a function for each instance of mapdl within the pool
 
         Parameters
@@ -209,7 +231,7 @@ class LocalMapdlPool:
 
         Returns
         -------
-        output : list
+        list
             A list containing the return values for ``func``.  Failed
             runs will not return an output.  Since the returns are not
             necessarily in the same order as ``iterable``, you may
@@ -247,7 +269,7 @@ class LocalMapdlPool:
         if not len(self):
             # instances could still be spawning...
             if not all(v is None for v in self._instances):
-                raise RuntimeError('No MAPDL instances available.')
+                raise RuntimeError("No MAPDL instances available.")
 
         results = []
 
@@ -258,15 +280,15 @@ class LocalMapdlPool:
 
         pbar = None
         if progress_bar:
-            pbar = tqdm(total=n, desc='MAPDL Running')
+            pbar = tqdm(total=n, desc="MAPDL Running")
 
         @threaded_daemon
-        def func_wrapper(obj, func, timeout, args=None):
+        def func_wrapper(obj, func, timeout, args=None, name=''):
             """Expect obj to be an instance of Mapdl"""
             complete = [False]
 
             @threaded_daemon
-            def run():
+            def run(name=''):
                 if args is not None:
                     if isinstance(args, (tuple, list)):
                         results.append(func(obj, *args))
@@ -276,7 +298,7 @@ class LocalMapdlPool:
                     results.append(func(obj))
                 complete[0] = True
 
-            run_thread = run()
+            run_thread = run(name='map.run')
             if timeout:
                 tstart = time.time()
                 while not complete[0]:
@@ -285,8 +307,7 @@ class LocalMapdlPool:
                         break
 
                 if not complete[0]:
-                    LOG.error('Killed instance due to timeout of %f seconds',
-                              timeout)
+                    LOG.error("Killed instance due to timeout of %f seconds", timeout)
                     obj.exit()
             else:
                 run_thread.join()
@@ -304,8 +325,11 @@ class LocalMapdlPool:
                             try:
                                 shutil.rmtree(obj.directory)
                             except Exception as e:
-                                LOG.warning('Unable to remove directory at %s:\n%s',
-                                            obj.directory, str(e))
+                                LOG.warning(
+                                    "Unable to remove directory at %s:\n%s",
+                                    obj.directory,
+                                    str(e),
+                                )
 
             obj.locked = False
             if pbar:
@@ -318,7 +342,7 @@ class LocalMapdlPool:
                 # grab the next available instance of mapdl
                 instance = self.next_available()
                 instance.locked = True
-                threads.append(func_wrapper(instance, func, timeout, args))
+                threads.append(func_wrapper(instance, func, timeout, args, name='Map_Thread'))
 
             if close_when_finished:
                 # start closing any instances that are not in execution
@@ -330,7 +354,7 @@ class LocalMapdlPool:
                     try:
                         instance.exit()
                     except Exception as e:
-                        LOG.error('Failed to close instance', exc_info=True)
+                        LOG.error("Failed to close instance", exc_info=True)
 
             else:
                 # wait for all threads to complete
@@ -348,8 +372,15 @@ class LocalMapdlPool:
 
         return results
 
-    def run_batch(self, files, clear_at_start=True, progress_bar=True,
-                  close_when_finished=False, timeout=None, wait=True):
+    def run_batch(
+        self,
+        files,
+        clear_at_start=True,
+        progress_bar=True,
+        close_when_finished=False,
+        timeout=None,
+        wait=True,
+    ):
         """Run a batch of input files on the pool.
 
         Parameters
@@ -386,7 +417,7 @@ class LocalMapdlPool:
 
         Returns
         -------
-        outputs : list
+        list
             List of text outputs from MAPDL for each batch run.  Not
             necessarily in the order of the inputs. Failed runs will
             not return an output.  Since the returns are not
@@ -406,7 +437,7 @@ class LocalMapdlPool:
         # check all files exist before running
         for filename in files:
             if not os.path.isfile(filename):
-                raise FileNotFoundError('Unable to locate file %s' % filename)
+                raise FileNotFoundError("Unable to locate file %s" % filename)
 
         def run_file(mapdl, input_file):
             if clear_at_start:
@@ -420,16 +451,16 @@ class LocalMapdlPool:
         """Wait until an instance of mapdl is available and return that instance.
 
         Parameters
-        --------
+        ----------
         return_index : bool, optional
             Return the index along with the instance.  Default ``False``.
 
         Returns
-        --------
-        mapdl : MapdlGrpc
+        -------
+        pyansys.MapdlGrpc
             Instance of MAPDL.
 
-        index : int
+        int
             Index within the pool of the instance of MAPDL.  By
             default this is not returned.
 
@@ -454,7 +485,7 @@ class LocalMapdlPool:
                     if not instance.busy:
                         # double check that this instance is alive:
                         try:
-                            instance.inquire('JOBNAME')
+                            instance.inquire("", "JOBNAME")
                         except:
                             instance.exit()
                             continue
@@ -491,7 +522,7 @@ class LocalMapdlPool:
                 except:
                     pass
                 self._instances[index] = None
-                LOG.debug('Exited instance: %s', str(instance))
+                # LOG.debug("Exited instance: %s", str(instance))
 
         threads = []
         for i, instance in enumerate(self):
@@ -519,18 +550,19 @@ class LocalMapdlPool:
                 yield instance
 
     @threaded_daemon
-    def _spawn_mapdl(self, index, port=None, pbar=None):
+    def _spawn_mapdl(self, index, port=None, pbar=None, name=''):
         """Spawn a mapdl instance at an index"""
         # create a new temporary directory for each instance
         run_location = create_temp_dir(self._root_dir)
-        self._instances[index] = launch_mapdl(run_location=run_location,
-                                              port=port, **self._spawn_kwargs)
-        LOG.debug('Spawned instance: %d', index)
+        self._instances[index] = launch_mapdl(
+            run_location=run_location, port=port, **self._spawn_kwargs
+        )
+        # LOG.debug("Spawned instance %d. Name '%s'", index, name)
         if pbar is not None:
             pbar.update(1)
 
     @threaded_daemon
-    def _monitor_pool(self, refresh=1.0):
+    def _monitor_pool(self, refresh=1.0, name=''):
         """Checks if instances within a pool have exited (failed) and
         restarts them.
         """
@@ -542,9 +574,9 @@ class LocalMapdlPool:
                     try:
                         # use the next port after the current available port
                         port = max(self._ports) + 1
-                        self._spawn_mapdl(index, port=port).join()
+                        self._spawn_mapdl(index, port=port, name=f'Instance {index}').join()
                     except Exception as e:
-                        logging.error(e, exc_info=True)
+                        LOG.error(e, exc_info=True)
             time.sleep(refresh)
 
     @property
@@ -552,4 +584,4 @@ class LocalMapdlPool:
         return [inst._port for inst in self if inst is not None]
 
     def __repr__(self):
-        return 'MAPDL Pool with %d active instances' % len(self)
+        return "MAPDL Pool with %d active instances" % len(self)
